/***************************************************************************
 *                           qgisinterface.cpp
 *                            Abstract base class for interfaces to functions in QgisApp
 *                           -------------------
 *      begin                : 2004-02-11
 *      copyright            : (C) 2004 by Gary E.Sherman
 *      email                : sherman at mrcc.com
 * ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ****************************************************************************/
/* $Id: qgisinterface.cpp 9138 2008-08-23 21:37:31Z jef $ */

#include "qgisinterface.h"

QgisInterface::QgisInterface()
{


}

QgisInterface::~QgisInterface()
{
}
